@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import collections
 import copy
 import warnings
 
@@ -9,10 +8,107 @@ from numpy.typing import ArrayLike
 
 from ._common import num_nodes_per_cell
 
+topological_dimension = {
+    "line": 1,
+    "polygon": 2,
+    "triangle": 2,
+    "quad": 2,
+    "tetra": 3,
+    "hexahedron": 3,
+    "wedge": 3,
+    "pyramid": 3,
+    "line3": 1,
+    "triangle6": 2,
+    "quad9": 2,
+    "tetra10": 3,
+    "hexahedron27": 3,
+    "wedge18": 3,
+    "pyramid14": 3,
+    "vertex": 0,
+    "quad8": 2,
+    "hexahedron20": 3,
+    "triangle10": 2,
+    "triangle15": 2,
+    "triangle21": 2,
+    "line4": 1,
+    "line5": 1,
+    "line6": 1,
+    "tetra20": 3,
+    "tetra35": 3,
+    "tetra56": 3,
+    "quad16": 2,
+    "quad25": 2,
+    "quad36": 2,
+    "triangle28": 2,
+    "triangle36": 2,
+    "triangle45": 2,
+    "triangle55": 2,
+    "triangle66": 2,
+    "quad49": 2,
+    "quad64": 2,
+    "quad81": 2,
+    "quad100": 2,
+    "quad121": 2,
+    "line7": 1,
+    "line8": 1,
+    "line9": 1,
+    "line10": 1,
+    "line11": 1,
+    "tetra84": 3,
+    "tetra120": 3,
+    "tetra165": 3,
+    "tetra220": 3,
+    "tetra286": 3,
+    "wedge40": 3,
+    "wedge75": 3,
+    "hexahedron64": 3,
+    "hexahedron125": 3,
+    "hexahedron216": 3,
+    "hexahedron343": 3,
+    "hexahedron512": 3,
+    "hexahedron729": 3,
+    "hexahedron1000": 3,
+    "wedge126": 3,
+    "wedge196": 3,
+    "wedge288": 3,
+    "wedge405": 3,
+    "wedge550": 3,
+    "VTK_LAGRANGE_CURVE": 1,
+    "VTK_LAGRANGE_TRIANGLE": 2,
+    "VTK_LAGRANGE_QUADRILATERAL": 2,
+    "VTK_LAGRANGE_TETRAHEDRON": 3,
+    "VTK_LAGRANGE_HEXAHEDRON": 3,
+    "VTK_LAGRANGE_WEDGE": 3,
+    "VTK_LAGRANGE_PYRAMID": 3,
+}
+
+
+class CellBlock:
+    def __init__(
+        self,
+        cell_type: str,
+        data: list | np.ndarray,
+        tags: list[str] | None = None,
+    ):
+        self.type = cell_type
+        self.data = data
+
+        if cell_type.startswith("polyhedron"):
+            self.dim = 3
+        else:
+            self.data = np.asarray(self.data)
+            self.dim = topological_dimension[cell_type]
+
+        self.tags = [] if tags is None else tags
 
-class CellBlock(collections.namedtuple("CellBlock", ["type", "data"])):
     def __repr__(self):
-        return f"<meshio CellBlock, type: {self.type}, num cells: {len(self.data)}>"
+        items = [
+            "meshio CellBlock",
+            f"type: {self.type}",
+            f"num cells: {len(self.data)}",
+            f"tags: {self.tags}",
+        ]
+        return "<" + ", ".join(items) + ">"
 
     def __len__(self):
         return len(self.data)
@@ -112,11 +208,11 @@ class Mesh:
         ]
         if len(self.cells) > 0:
             lines.append("  Number of cells:")
-            for cell_type, elems in self.cells:
-                string = cell_type
-                if cell_type in special_cells:
-                    string += f"({elems.shape[1]})"
-                lines.append(f"    {string}: {len(elems)}")
+            for cell_block in self.cells:
+                string = cell_block.type
+                if cell_block.type in special_cells:
+                    string += f"({cell_block.data.shape[1]})"
+                lines.append(f"    {string}: {len(cell_block)}")
         else:
             lines.append("  No cells.")
 
@@ -164,10 +260,10 @@ class Mesh:
     @property
     def cells_dict(self):
         cells_dict = {}
-        for cell_type, data in self.cells:
-            if cell_type not in cells_dict:
-                cells_dict[cell_type] = []
-            cells_dict[cell_type].append(data)
+        for cell_block in self.cells:
+            if cell_block.type not in cells_dict:
+                cells_dict[cell_block.type] = []
+            cells_dict[cell_block.type].append(cell_block.data)
         # concatenate
         for key, value in cells_dict.items():
             cells_dict[key] = np.concatenate(value)
@@ -178,10 +274,10 @@ class Mesh:
         cell_data_dict = {}
         for key, value_list in self.cell_data.items():
             cell_data_dict[key] = {}
-            for value, (cell_type, _) in zip(value_list, self.cells):
-                if cell_type not in cell_data_dict[key]:
-                    cell_data_dict[key][cell_type] = []
-                cell_data_dict[key][cell_type].append(value)
+            for value, cell_block in zip(value_list, self.cells):
+                if cell_block.type not in cell_data_dict[key]:
+                    cell_data_dict[key][cell_block.type] = []
+                cell_data_dict[key][cell_block.type].append(value)
 
             for cell_type, val in cell_data_dict[key].items():
                 cell_data_dict[key][cell_type] = np.concatenate(val)
