@@ -7,7 +7,6 @@ import warnings
 import numpy as np
 
 from ..__about__ import __version__
-from .._common import topological_dimension
 from .._files import open_file
 from .._helpers import register_format
 from .._mesh import Mesh
@@ -165,36 +164,35 @@ def _read_cells(f, netgen_cell_type, cells, cells_index, skip_every_other_line=F
             line, _ = _fast_forward_over_blank_lines(f)
 
 
-def _write_cells(f, block, index=None):
-    if len(block) == 0:
+def _write_cells(f, cell_block, index=None):
+    if len(cell_block) == 0:
         return
-    pmap = np.array(meshio_to_netgen_pmap[block.type])
-    dim = topological_dimension[block.type]
+    pmap = np.array(meshio_to_netgen_pmap[cell_block.type])
     post_data = []
     pre_data = []
     i_index = 0
-    if dim == 0:
+    if cell_block.dim == 0:
         post_data = [1]
         i_index = 1
-    elif dim == 1:
+    elif cell_block.dim == 1:
         pre_data = [1, 0]
         post_data = [-1, -1, 0, 0, 1, 0, 1, 0]
-    elif dim == 2:
+    elif cell_block.dim == 2:
         pre_data = [1, 1, 0, 0, len(pmap)]
         i_index = 1
-    elif dim == 3:
+    elif cell_block.dim == 3:
         pre_data = [1, len(pmap)]
     else:
-        raise ValueError(f"Invalid cell dimension: {dim}")
+        raise ValueError(f"Invalid cell dimension: {cell_block.dim}")
 
     col1 = len(pre_data)
     col2 = col1 + len(pmap)
     col3 = col2 + len(post_data)
 
-    pi = np.zeros((len(block), col3), dtype=np.int32)
-    pi[:, :col1] = np.repeat([pre_data], len(block), axis=0)
-    pi[:, col1:col2] = block.data[:, pmap] + 1
-    pi[:, col2:] = np.repeat([post_data], len(block), axis=0)
+    pi = np.zeros((len(cell_block), col3), dtype=np.int32)
+    pi[:, :col1] = np.repeat([pre_data], len(cell_block), axis=0)
+    pi[:, col1:col2] = cell_block.data[:, pmap] + 1
+    pi[:, col2:] = np.repeat([post_data], len(cell_block), axis=0)
     if index is not None:
         pi[:, i_index] = index
     np.savetxt(f, pi, "%i")
@@ -216,10 +214,10 @@ def _write_codim_domain_data(f, mesh, cells_index, dim, codim):
     # set generic default names (is this appropriate/useful?)
     if len(data) == 0:
         indices = set()
-        for block, index in zip(mesh.cells, cells_index):
+        for cell_block, index in zip(mesh.cells, cells_index):
             if index is None:
                 continue
-            if topological_dimension[block.type] == dim - codim:
+            if cell_block.dim == dim - codim:
                 indices = indices.union(set(index))
 
         for idx in indices:
@@ -384,8 +382,8 @@ def write_buffer(f, mesh, float_fmt):
         if cells_index is None:
             cells_index = [None] * len(mesh.cells)
 
-    for block in mesh.cells:
-        cells_per_dim[topological_dimension[block.type]] += len(block)
+    for cell_block in mesh.cells:
+        cells_per_dim[cell_block.dim] += len(cell_block)
 
     f.write(f"# Generated by meshio {__version__}\n")
     f.write("mesh3d\n\n")
@@ -399,25 +397,25 @@ def write_buffer(f, mesh, float_fmt):
     f.write("\n# surfnr    bcnr   domin  domout      np      p1      p2      p3\n")
     f.write("surfaceelements\n")
     f.write(f"{cells_per_dim[2]}\n")
-    for block, index in zip(mesh.cells, cells_index):
-        if topological_dimension[block.type] == 2:
-            _write_cells(f, block, index)
+    for cell_block, index in zip(mesh.cells, cells_index):
+        if cell_block.dim == 2:
+            _write_cells(f, cell_block, index)
 
     f.write("\n#  matnr      np      p1      p2      p3      p4\n")
     f.write("volumeelements\n")
     f.write(f"{cells_per_dim[3]}\n")
-    for block, index in zip(mesh.cells, cells_index):
-        if topological_dimension[block.type] == 3:
-            _write_cells(f, block, index)
+    for cell_block, index in zip(mesh.cells, cells_index):
+        if cell_block.dim == 3:
+            _write_cells(f, cell_block, index)
 
     f.write(
         "\n# surfid  0   p1   p2   trignum1    trignum2   domin/surfnr1    domout/surfnr2   ednr1   dist1   ednr2   dist2\n",
     )
     f.write("edgesegmentsgi2\n")
     f.write(f"{cells_per_dim[1]}\n")
-    for block, index in zip(mesh.cells, cells_index):
-        if topological_dimension[block.type] == 1:
-            _write_cells(f, block, index)
+    for cell_block, index in zip(mesh.cells, cells_index):
+        if cell_block.dim == 1:
+            _write_cells(f, cell_block, index)
 
     f.write("\n#          X             Y             Z\n")
     f.write("points\n")
@@ -433,9 +431,9 @@ def write_buffer(f, mesh, float_fmt):
     f.write("\n#          pnum             index\n")
     f.write("pointelements\n")
     f.write(f"{cells_per_dim[0]}\n")
-    for block, index in zip(mesh.cells, cells_index):
-        if topological_dimension[block.type] == 0:
-            _write_cells(f, block, index)
+    for cell_block, index in zip(mesh.cells, cells_index):
+        if cell_block.dim == 0:
+            _write_cells(f, cell_block, index)
 
     # currently, there is no better place for identification data
     if isinstance(mesh.info, dict):
